const Docma = require('docma');
const Package = require('./package');

Docma.create()
    .build({
        app: {
            title: Package.name,
            base: '/tatsumaki.js',
            entrance: 'content:readme',
            routing: 'query',
            server: Docma.ServerType.GITHUB
        },
        markdown: {
            gfm: true,
            tables: true,
            breaks: false,
            pedantic: false,
            sanitize: false,
            smartLists: false,
            smartypants: false,
            tasks: false,
            emoji: true
        },
        src: [
            { readme: './README.md' },
            { tatsumaki: './src/*/**/*.js' }
        ],
        dest: './docs',
        debug: true,
        jsdoc: { package: './package.json' },
        template: {
            options: {
                title: Package.name,
                navItems: [
                    {
                        label: 'Readme',
                        href: '?content=readme'
                    },
                    {
                        label: 'Documentation',
                        href: '?api=tatsumaki',
                        iconClass: 'ico-book'
                    },
                    {
                        label: 'GitHub',
                        href: Package.homepage,
                        target: '_blank',
                        iconClass: 'ico-md ico-github'
                    }
                ]
            }
        }
    })
    .catch(console.error);
